==> v4.2.4.tar.gz: 2fauth/resources/lang/ru/groups.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Groups Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'groups' => 'Группы',
    'create_group' => 'Создать новую группу',
    'show_group_selector' => 'Показать выбор групп',
    'hide_group_selector' => 'Скрыть выбор группы',
    'select_accounts_to_show' => 'Выберите группу аккаунтов для отображения',
    'manage_groups' => 'Управление группами',
    'active_group' => 'Активные группы',
    'manage_groups_legend' => 'Вы можете создать группы для организации ваших учетных записей. Все аккаунты остаются видимыми в служебной группе \'Все\', независимо от группы, к которой они принадлежат.',
    'deleting_group_does_not_delete_accounts' => 'Удаление группы не удаляет учетные записи',
    'move_selected_to' => 'Переместить выбранные в',
    'move_selected_to_group' => 'Переместить выделенное в группу',
    'no_group' => 'Без группы',
    'change_group' => 'Изменить группу',
    'group_successfully_created' => 'Группа успешно создана',
    'group_name_saved' => 'Название группы сохранено',
    'group_successfully_deleted' => 'Группа успешно удалена',
    'forms' => [
        'new_group' => 'Новая группа',
        'new_name' => 'Новое имя',
        'rename_group' => 'Переименовать группу',
    ],
    'confirm' => [
        'delete' => 'Вы действительно хотите удалить эту группу?',
    ],
];

==> v5.0.3.tar.gz: 2fauth/resources/lang/ru/groups.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Groups Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'groups' => 'Группы',
    'create_group' => 'Создать новую группу',
    'show_group_selector' => 'Показать выбор групп',
    'hide_group_selector' => 'Скрыть выбор группы',
    'select_accounts_to_show' => 'Выберите группу учётных записей для отображения',
    'manage_groups' => 'Управление группами',
    'active_group' => 'Активные группы',
    'manage_groups_legend' => 'Вы можете создать группы для организации ваших учетных записей. Все учётные записи остаются видимыми в служебной группе \'Все\', независимо от группы, к которой они принадлежат.',
    'deleting_group_does_not_delete_accounts' => 'Удаление группы не удаляет учетные записи',
    'move_selected_to' => 'Переместить выбранные в',
    'move_selected_to_group' => 'Переместить выделенное в группу',
    'no_group' => 'Без группы',
    'change_group' => 'Изменить группу',
    'group_successfully_created' => 'Группа успешно создана',
    'group_name_saved' => 'Название группы сохранено',
    'group_successfully_deleted' => 'Группа успешно удалена',
    'forms' => [
        'new_group' => 'Новая группа',
        'new_name' => 'Новое имя',
        'rename_group' => 'Переименовать группу',
    ],
    'confirm' => [
        'delete' => 'Вы действительно хотите удалить эту группу?',
    ],
];
